@@ -1,13 +1,13 @@
-#' Beta probability density function
+#' Probability density function of the beta distribution
 #'
 #' @description The function computes the probability density function of the beta distribution with a mean-precision parameterization.
-#' It can also  compute the probability density function of the augmented beta distribution by assigning positive probabilities to zero and one and a (continuous) beta density to the interval (0,1).
+#' It can also  compute the probability density function of the augmented beta distribution by assigning positive probabilities to zero and/or one values and a (continuous) beta density to the interval (0,1).
 #'
 #' @param x a vector of quantiles.
-#' @param mu the mean parameter of the beta distribution. It must lie in (0, 1).
-#' @param phi the precision parameter of the Beta distribution. It must be a positive real value.
-#' @param q0 the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
-#' @param q1 the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
+#' @param mu the mean parameter. It must lie in (0, 1).
+#' @param phi the precision parameter. It must be a real positive value.
+#' @param q0 the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
+#' @param q1 the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
 #'
 #' @return A vector with the same length as \code{x}.
 #'
@@ -25,9 +25,9 @@
 #' and \eqn{q_0+q_1<1}.
 #'
 #' @examples
-#' dBeta_mu(x = c(.5,.7,.8), mu = .3, phi = 20)
-#' dBeta_mu(x = c(.5,.7,.8), mu = .3, phi = 20, q0 = .2)
-#' dBeta_mu(x = c(.5,.7,.8), mu = .3, phi = 20, q0 = .2, q1= .1)
+#' dBeta(x = c(.5,.7,.8), mu = .3, phi = 20)
+#' dBeta(x = c(.5,.7,.8), mu = .3, phi = 20, q0 = .2)
+#' dBeta(x = c(.5,.7,.8), mu = .3, phi = 20, q0 = .2, q1= .1)
 #'
 #' @references{
 #' Ferrari, S.L.P., Cribari-Neto, F. (2004). Beta Regression for Modeling Rates and Proportions. Journal of Applied Statistics, \bold{31}(7), 799--815. doi:10.1080/0266476042000214501
@@ -38,7 +38,7 @@
 #' @export
 #'
 #'
-dBeta_mu <- function(x, mu, phi, q0 = NULL, q1 = NULL){
+dBeta <- function(x, mu, phi, q0 = NULL, q1 = NULL){
   q0 <- ifelse(is.null(q0),0,q0)
   q1 <- ifelse(is.null(q1),0,q1)
   if (any(x < 0 | x > 1)) stop("x has to be between 0 and 1")
@@ -59,27 +59,27 @@ dBeta_mu <- function(x, mu, phi, q0 = NULL, q1 = NULL){
 }
 
 
-#' Flexible beta probability density function
+#' Probability density function of the flexible beta distribution
 #'
 #' @description The function computes the probability density function of the flexible beta distribution.
-#' It can also  compute the probability density function of the augmented flexible beta distribution by assigning positive probabilities to zero and one and a (continuous) flexible beta density to the interval (0,1).
+#' It can also  compute the probability density function of the augmented flexible beta distribution by assigning positive probabilities to zero and/or one values and a (continuous) flexible beta density to the interval (0,1).
 #'
 #' @param x a vector of quantiles.
-#' @param mu the mean parameter of the flexible beta distribution. It must lie in (0, 1).
-#' @param phi the precision parameter of the flexible beta distribution. It must be a positive real value.
+#' @param mu the mean parameter. It must lie in (0, 1).
+#' @param phi the precision parameter. It must be a real positive value.
 #' @param p the mixing weight. It must lie in (0, 1).
-#' @param w the normalized distance among clusters. It must lie in (0, 1).
-#' @param q0 the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
-#' @param q1 the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
+#' @param w the normalized distance among component means. It must lie in (0, 1).
+#' @param q0 the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
+#' @param q1 the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
 #'
 #' @return A vector with the same length as \code{x}.
 #'
-#' @details The FB distribution is a special mixture of two beta distributions with density
-#' \deqn{f_{FB}(x;\mu,\phi,p,w)=p f_B(x;\lambda_1,\phi)+(1-p)f_B(x;\lambda_1,\phi)}
+#' @details The FB distribution is a special mixture of two beta distributions with probability density function
+#' \deqn{f_{FB}(x;\mu,\phi,p,w)=p f_B(x;\lambda_1,\phi)+(1-p)f_B(x;\lambda_2,\phi),}
 #'  for \eqn{0<x<1}, where \eqn{f_B(x;\cdot,\cdot)} is the beta density with a mean-precision parameterization.
-#'  Moreover, \eqn{0<\mu=p\lambda_1+(1-p)\lambda_2<1} is the overall mean,\eqn{\phi>0} is a precision parameter,
-#'  \eqn{0<p<1} is the mixing weight, and \eqn{0<w<1} is the  normalized distance between component means.
-#'  The latter are \eqn{\lambda_1=\mu+(1-p)\tilde{w}} and \eqn{\lambda_2=\mu-p\tilde{w}}, where \eqn{\tilde{w}=w\min{\mu/p, (1-\mu)/(1-p)}}.
+#'  Moreover, \eqn{0<\mu=p\lambda_1+(1-p)\lambda_2<1} is the overall mean, \eqn{\phi>0} is a precision parameter,
+#'  \eqn{0<p<1} is the mixing weight,  \eqn{0<w<1} is the  normalized distance between component means, and
+#'  \eqn{\lambda_1=\mu+(1-p)w} and \eqn{\lambda_2=\mu-pw} are the means of the first and second component of the mixture, respectively.
 #'
 #' The augmented FB distribution has density
 #' \itemize{
@@ -120,7 +120,7 @@ dFB <- function(x, mu, phi, p, w, q0 = NULL, q1 = NULL){
   lambda1 <- mu + (1-p)*wtilde
   lambda2 <- mu-p*wtilde
 
-  fun <- (1-q0-q1)*(p*dBeta_mu(x,lambda1,phi) + (1-p)*dBeta_mu(x,lambda2,phi))
+  fun <- (1-q0-q1)*(p*dBeta(x,lambda1,phi) + (1-p)*dBeta(x,lambda2,phi))
   fun[which(x==0)] <- q0
   fun[which(x==1)] <- q1
 
@@ -128,23 +128,23 @@ dFB <- function(x, mu, phi, p, w, q0 = NULL, q1 = NULL){
 }
 
 
-#' Variance-inflated beta probability density function
+#' Probability density function of the variance-inflated beta distribution
 #'
 #' @description The function computes the probability density function of the variance-inflated beta distribution.
-#' It can also  compute the probability density function of the augmented variance-inflated beta distribution by assigning positive probabilities to zero and one and a (continuous) variance-inflated beta density to the interval (0,1).
+#' It can also  compute the probability density function of the augmented variance-inflated beta distribution by assigning positive probabilities to zero and/or one values and a (continuous) variance-inflated beta density to the interval (0,1).
 #'
 #' @param x a vector of quantiles.
-#' @param mu the mean parameter of the variance-inflated beta distribution. It must lie in (0, 1).
-#' @param phi the precision parameter of the variance-Inflated distribution. It must be a positive real value.
+#' @param mu the mean parameter. It must lie in (0, 1).
+#' @param phi the precision parameter. It must be a real positive value.
 #' @param p the mixing weight. It must lie in (0, 1).
 #' @param k the extent of the variance inflation. It must lie in (0, 1).
-#' @param q0 the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
-#' @param q1 the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
+#' @param q0 the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
+#' @param q1 the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
 #'
 #' @return A vector with the same length as \code{x}.
 #'
-#' @details The VIB distribution is a special mixture of two beta distributions with density
-#' \deqn{f_{VIB}(x;\mu,\phi,p,k)=p f_B(x;\mu,\phi k)+(1-p)f_B(x;\mu,\phi)}
+#' @details The VIB distribution is a special mixture of two beta distributions with probability density function
+#' \deqn{f_{VIB}(x;\mu,\phi,p,k)=p f_B(x;\mu,\phi k)+(1-p)f_B(x;\mu,\phi),}
 #'  for \eqn{0<x<1}, where \eqn{f_B(x;\cdot,\cdot)} is the beta density with a mean-precision parameterization.
 #'  Moreover, \eqn{0<p<1} is the mixing weight, \eqn{0<\mu<1} represents the overall (as well as mixture component)
 #'  mean, \eqn{\phi>0} is a precision parameter, and \eqn{0<k<1} determines the extent of the variance inflation.
@@ -182,26 +182,26 @@ dVIB <- function(x, mu, phi, p, k, q0 = NULL, q1 = NULL){
   if (any(q1 < 0 | q1 > 1)) stop("Parameter q1 has to be between 0 and 1")
   if (any(q0+q1>1)) stop("The sum of q0 and q1 must be less than 1")
 
-  fun <- (1-q0-q1)*(p*dBeta_mu(x,mu,phi*k) + (1-p)*dBeta_mu(x,mu,phi))
+  fun <- (1-q0-q1)*(p*dBeta(x,mu,phi*k) + (1-p)*dBeta(x,mu,phi))
   fun[which(x==0)] <- q0
   fun[which(x==1)] <- q1
 
   return(fun)
 }
 
-#' Beta-binomial probability mass function
+#' Probability mass function of the beta-binomial distribution
 #'
 #' The function computes the probability mass function of the beta-binomial distribution.
 #' @param x a vector of quantiles.
 #' @param size the total number of trials.
 #' @param mu the mean parameter. It must lie in (0, 1).
 #' @param theta the overdispersion parameter. It must  lie in (0, 1).
-#' @param phi the precision parameter. It is an alternative way to specify the \code{theta} parameter. It must be a positive real value.
+#' @param phi the precision parameter, an alternative way to specify the overdispersion parameter \code{theta}. It must be a real positive value.
 #'
 #' @return A vector with the same length as \code{x}.
 #'
 #' @details The beta-binomial distribution has probability mass function
-#' \deqn{{n\choose x} \frac{\Gamma{(\phi)}}{\Gamma{(\mu\phi)}\Gamma{((1-\mu)\phi)}} \frac{\Gamma{(\mu\phi+x)}\Gamma{((1-\mu)\phi + n - x)}}{\Gamma{(\phi + n)}},}
+#' \deqn{f_{BB}(x;\mu,\phi)={n\choose x} \frac{\Gamma{(\phi)}}{\Gamma{(\mu\phi)}\Gamma{((1-\mu)\phi)}} \frac{\Gamma{(\mu\phi+x)}\Gamma{((1-\mu)\phi + n - x)}}{\Gamma{(\phi + n)}},}
 #' for \eqn{x \in \lbrace 0, 1, \dots, n \rbrace}, where \eqn{0<\mu<1} identifies the mean and \eqn{\phi=(1-\theta)/\theta >0} is the precision parameter.
 #'
 #' @examples dBetaBin(x = 5, size = 10, mu = .3, phi = 10)
@@ -238,26 +238,27 @@ dBetaBin <- function(x, size, mu, theta=NULL, phi=NULL){
              ))
 }
 
-#' Flexible beta-binomial probability mass function
+#' Probability mass function of the flexible beta-binomial distribution
 #'
 #' The function computes the probability mass function of the flexible beta-binomial distribution.
 #'
 #' @param x a vector of quantiles.
 #' @param size the total number of trials.
 #' @param mu the mean parameter. It must lie in (0, 1).
-#' @param theta the overdispersion paramete. It must  lie in (0, 1).
-#' @param phi the precision parameter. It is an alternative way to specify the \code{theta} parameter. It must be a positive real value.
+#' @param theta the overdispersion parameter. It must  lie in (0, 1).
+#' @param phi the precision parameter, an alternative way to specify the overdispersion parameter \code{theta}. It must be a real positive value.
 #' @param p the mixing weight. It must lie in (0, 1).
-#' @param w the normalized distance among clusters. It must lie in (0, 1).
+#' @param w the normalized distance among component means. It must lie in (0, 1).
 #'
 #' @return A vector with the same length as \code{x}.
 #'
-#' @details The FBB distribution is a special mixture of two beta-binomial distributions
-#' \deqn{p BB(x;\lambda_1,\phi)+(1-p)BB(x;\lambda_2,\phi)}
-#'  for \eqn{x \in \lbrace 0, 1, \dots, n \rbrace} where \eqn{BB(x;\cdot,\cdot)} is the beta-binomial distribution with a mean-precision parameterization.
-#'  Moreover, \eqn{\phi=(1-\theta)/\theta}, \eqn{0<p<1} is the mixing weight, \eqn{\phi>0} is a precision parameter,
-#'  \eqn{\lambda_1=\mu+(1-p)w} and \eqn{\lambda_2=\mu-pw} are the component means of the first and second component of the mixture,
-#'  \eqn{0<\mu=p\lambda_1+(1-p)\lambda_2<1} is the overall mean, and \eqn{0<w<1} is the  normalized distance between clusters.
+#' @details The FBB distribution is a special mixture of two beta-binomial distributions with probability mass function
+#' \deqn{f_{FBB}(x;\mu,\phi,p,w) = p BB(x;\lambda_1,\phi)+(1-p)BB(x;\lambda_2,\phi),}
+#'  for \eqn{x \in \lbrace 0, 1, \dots, n \rbrace}, where \eqn{BB(x;\cdot,\cdot)} is the beta-binomial distribution with a mean-precision parameterization.
+#'  Moreover, \eqn{\phi=(1-\theta)/\theta>0} is a precision parameter, \eqn{0<p<1} is the mixing weight, \eqn{0<\mu=p\lambda_1+(1-p)\lambda_2<1} is the overall mean,
+#'   \eqn{0<w<1} is the  normalized distance between component means, and
+#'  \eqn{\lambda_1=\mu+(1-p)w} and \eqn{\lambda_2=\mu-pw} are the scaled means of the first and second component of the mixture, respectively.
+#'
 #
 #' @examples dFBB(x = c(5,7,8), size=10, mu = .3, phi = 20, p = .5, w = .5)
 #'
@@ -298,18 +299,18 @@ dFBB <- function(x, size, mu, theta=NULL, phi=NULL, p, w){
 #' Draw density plots
 #'
 #' The function draws a curve corresponding to the probability density/mass function of the specified distribution (beta, flexible beta, variance-inflated beta, binomial, beta-binomial, or flexible beta-binomial).
-#' For beta, flexible beta, and variance-inflated beta, it also allows to plot the probability of augmentation in zero/one.
+#' For beta, flexible beta, and variance-inflated beta, it also allows to include the representation of the probability of augmentation in zero and/or one values.
 #' @param type a character specifying the distribution type to be plotted (\code{"Beta"}, \code{"FB"}, \code{"VIB"}, \code{"Bin"}, \code{"BetaBin"}, or \code{"FBB"}).
-#' @param size the total number of trials (to be specified if \code{type} is \code{"Bin"}, \code{"BetaBin"}, or \code{"FBB"}).
+#' @param size the total number of trials (to be specified only if \code{type} is \code{"Bin"}, \code{"BetaBin"}, or \code{"FBB"}).
 #' @param mu the mean parameter of the distribution. It must lie in (0, 1).
-#' @param theta the overdispersion parameter (to be specified if \code{type} is \code{"BetaBin"} or \code{"FBB"}). It must  lie in (0, 1).
-#' @param phi  the precision parameter (an alternative way to specify the \code{theta} parameter if \code{type} is \code{"BetaBin"} or \code{"FBB"}). It must be a positive real value.
-#' @param p  the mixing weight (to be specified if \code{type} is \code{"FB"} or \code{"VIB"}). It must lie in (0, 1).
-#' @param w  the normalized distance among clusters of the FB distribution (to be specified if \code{type = "FB"}). It must lie in (0, 1).
-#' @param k  the extent of the variance inflation (to be specified if \code{type = "VIB"}). It must lie in (0, 1).
-#' @param q0 the probability of augmentation in zero (it can be specified only if \code{type} is \code{"Beta"}, \code{"FB"}, or \code{"VIB"}). It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
-#' @param q1 the probability of augmentation in one (it can be specified only if \code{type} is \code{"Beta"}, \code{"FB"}, or \code{"VIB"}). It must lie in (0, 1). In case of no augmentation is \code{NULL} (default).
-#' @param ... additional arguments of \code{stat_function()}.
+#' @param theta the overdispersion parameter (to be specified only if \code{type} is \code{"BetaBin"} or \code{"FBB"}). It must  lie in (0, 1).
+#' @param phi  the precision parameter (if \code{type} is \code{"BetaBin"} or \code{"FBB"}, it represents an alternative way to specify the \code{theta} parameter). It must be a real positive value.
+#' @param p  the mixing weight (to be specified only if \code{type} is \code{"FB"}, \code{"VIB"}, or \code{"FBB"}). It must lie in (0, 1).
+#' @param w  the normalized distance among component means of the FB and FBB distributions (to be specified only if \code{type = "FB"}, or \code{type = "FBB"}). It must lie in (0, 1).
+#' @param k  the extent of the variance inflation (to be specified only if \code{type = "VIB"}). It must lie in (0, 1).
+#' @param q0 the probability of augmentation in zero (to be specified only if \code{type} is \code{"Beta"}, \code{"FB"}, or \code{"VIB"}). It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
+#' @param q1 the probability of augmentation in one (to be specified only if \code{type} is \code{"Beta"}, \code{"FB"}, or \code{"VIB"}). It must lie in (0, 1). In case of no augmentation, it is \code{NULL} (default).
+#' @param ... additional arguments of \code{\link{stat_function}}.
 #'
 #'
 #' @examples
@@ -343,64 +344,93 @@ dFBB <- function(x, size, mu, theta=NULL, phi=NULL, p, w){
 #' @export
 #'
 #'
-curve.density <- function(type = NULL, size = NULL, mu = NULL, theta = NULL, phi = NULL, p = NULL,
-                          w = NULL, k = NULL, q0 = NULL, q1 = NULL, ...){
-  if(is.null(mu) | ((is.null(phi)&(is.null(theta))) & type!="Bin")) stop("Specify parameters according to the chosen distribution")
-  if(type == "FB" & (is.null(p) | is.null(w))) stop("Specify parameters according to the chosen distribution")
-  if(type == "VIB" & (is.null(p) | is.null(k))) stop("Specify parameters according to the chosen distribution")
+curve.density <- function (type = NULL, size = NULL, mu = NULL, theta = NULL,
+                           phi = NULL, p = NULL, w = NULL, k = NULL, q0 = NULL, q1 = NULL,
+                           ...)
+{
+  if (is.null(mu) | ((is.null(phi) & (is.null(theta))) & type !=
+                     "Bin"))
+    stop("Specify parameters according to the chosen distribution")
+  if (type == "FB" & (is.null(p) | is.null(w)))
+    stop("Specify parameters according to the chosen distribution")
+  if (type == "VIB" & (is.null(p) | is.null(k)))
+    stop("Specify parameters according to the chosen distribution")
+  if (type == "Beta" & !is.null(p))
+    stop("Specify parameters according to the chosen distribution")
+  if (!(type %in% c("FB", "FBB")) & !is.null(w))
+    stop("Specify parameters according to the chosen distribution")
+  if (type != "VIB" & !is.null(k))
+    stop("Specify parameters according to the chosen distribution")
+  if (!(type %in% c("Beta", "FB", "VIB")) & !is.null(c(q0,
+                                                       q1)))
+    stop("Parameters q0 and q1 can be defined only for Beta, FB, or VIB distributions")
+  q0 <- ifelse(is.null(q0), 0, q0)
+  q1 <- ifelse(is.null(q1), 0, q1)
+  if ((type %in% c("FB", "Beta", "VIB"))) {
+    x <- seq(0, 1, length.out = 1000)
+    if (!is.null(size))
+      stop("Parameter size must not be specified if type is ''Beta'', ''FB'', or ''VIB''.")
+    if (type == "Beta") {
+      fun <- dBeta(x, mu, phi, q0, q1)
+    }
+    else if (type == "FB") {
+      fun <- dFB(x, mu = mu, phi = phi, p = p, w = w, q0 = q0,
+                 q1 = q1)
+    }
+    else if (type == "VIB") {
+      fun <- dVIB(x, mu = mu, phi = phi, p = p, k = k,
+                  q0 = q0, q1 = q1)
+    }
+    else stop("Please specify the type of distribution correctly.")
+    title.default <- paste0(type, " density function ", ifelse(q0 >
+                                                                 0 & q1 == 0, "with zero augmentation", ifelse(q0 ==
+                                                                                                                 0 & q1 > 0, "with one augmentation", ifelse(q0 >
+                                                                                                                                                               0 & q1 > 0, "with zero and one augmentation", ""))))
+    pp <- ggplot(data = data.frame(x = x[-c(1,length(x))], y = fun[-c(1,length(x))])) + geom_line(aes(x = x,
+                                                                                                      y = y), alpha = 1) + xlab("x") + ylab("Density") +
+      ggtitle(title.default) + theme_minimal()
+    if (q0 > 0) {
+      pp <- pp + geom_point(aes(x = x[1], y = q0), size = 2)+
+        geom_segment(aes(x = x[1], y = x[1],xend = x[1], yend = q0), linetype="dashed")
+    }
+    if (q1 > 0) {
+      pp <- pp + geom_point(aes(x = x[length(x)], y = q1),
+                            size = 2)+
+        geom_segment(aes(x = x[length(x)], y = x[1], xend = x[length(x)], yend = q1), linetype="dashed")
+    }
+  }
+  else if ((type %in% c("FBB", "Bin", "BetaBin"))) {
+    if (type == "FBB") {
+      if (!is.null(theta) & is.null(phi))
+        phi <- (1 - theta)/theta
+      if (is.null(theta) & is.null(phi))
+        stop("Please specify a value for theta or phi")
+      title.default <- paste0(type, " mass function ")
 
-  if(type == "Beta" & !is.null(p)) stop("Specify parameters according to the chosen distribution")
-  if(!(type %in% c("FB","FBB")) & !is.null(w)) stop("Specify parameters according to the chosen distribution")
-  if(type != "VIB" & !is.null(k)) stop("Specify parameters according to the chosen distribution")
-
-  if(!(type %in% c("Beta", "FB", "VIB")) & !is.null(c(q0,q1))) stop("Parameters q0 and q1 can be defined only for Beta, FB, or VIB distributions")
-  q0 <- ifelse(is.null(q0),0,q0)
-  q1 <- ifelse(is.null(q1),0,q1)
-
-  if((type %in% c("FB","Beta", "VIB"))){
-    x <- seq(0,1,length.out = 1000)
-    if(!is.null(size)) stop("Parameter size must not be specified if type is ''Beta'', ''FB'', or ''VIB''.")
-    if(type == "Beta") {
-      fun <- dBeta_mu(x,mu,phi, q0,q1)
-    } else if(type == "FB") {
-      fun <- dFB(x, mu = mu, phi = phi, p = p, w = w, q0 = q0, q1 = q1)
-    } else if(type == "VIB") {
-      fun <- dVIB(x, mu = mu, phi = phi, p = p, k = k, q0=q0,q1=q1)
-    } else stop("Please specify the type of distribution correctly.")
-
-    title.default <- paste0(type," density function ",
-                            ifelse(q0>0 & q1==0, "with zero augmentation",
-                                   ifelse(q0==0 & q1>0,"with one augmentation",
-                                          ifelse(q0>0 & q1>0,"with zero and one augmentation", "" ))))
-
-    pp <- ggplot(data = data.frame(x = x, y = fun))+
-      geom_line(aes(x=x, y=y), alpha=1) +
-      xlab("x") + ylab("Density") + ggtitle(title.default)+ theme_minimal()
-  if(q0>0){
-    pp <- pp +  geom_point(aes(x=x[1], y=y[1]),size=2)}
-  if(q1>0){
-     pp <- pp+ geom_point(aes(x=x[length(x)], y=y[length(x)]),size=2)
-}
-    } else if((type %in% c("FBB","Bin", "BetaBin"))){
-
-      if(type=="FBB"){
-        if(!is.null(theta) & is.null(phi)) phi <- (1-theta)/theta
-        if(is.null(theta) & is.null(phi)) stop("Please specify a value for theta or phi")
-        prob <- dFBB(0:size, size=size, mu=mu, phi=phi, w=.6, p=.5)
-      } else if(type=="BetaBin"){
-        if(!is.null(theta) & is.null(phi)) phi <- (1-theta)/theta
-        if(is.null(theta) & is.null(phi)) stop("Please specify a value for theta or phi")
-        prob <- dBetaBin(0:size, size=size, mu=mu, phi=phi)
-      } else prob <- dbinom(0:size, size=size, prob=mu)
-
-      y <- NULL
-      pp <- ggplot(data=data.frame(y=0:size, prob=prob)) +
-        geom_point(aes(x=y, y=prob),size=2) +
-        geom_line(aes(x=y, y=prob),alpha=.3) +
-        ylim(0,max(prob)+.05)+ xlab("x") + ylab("Probability")+theme_minimal()
-
-
-    } else stop("Error: please specify a valide type argument.")
+      prob <- dFBB(0:size, size = size, mu = mu, phi = phi,
+                   w = 0.6, p = 0.5)
+    }
+    else if (type == "BetaBin") {
+      title.default <- paste0("Beta binomial mass function ")
+      if (!is.null(theta) & is.null(phi))
+        phi <- (1 - theta)/theta
+      if (is.null(theta) & is.null(phi))
+        stop("Please specify a value for theta or phi")
+      prob <- dBetaBin(0:size, size = size, mu = mu, phi = phi)
+    }
+    else {
+      prob <- dbinom(0:size, size = size, prob = mu)
+      title.default <- paste0("Binomial mass function ")
 
+    }
+    y <- NULL
+    pp <- ggplot(data = data.frame(y = 0:size, prob = prob)) +
+      geom_point(aes(x = y, y = prob), size = 2) + geom_line(aes(x = y,
+                                                                 y = prob), alpha = 0.3) + ylim(0, max(prob) + 0.05) +
+      xlab("x") + ylab("Probability") + ggtitle(title.default)+ theme_minimal()
+  }
+  else stop("Error: please specify a valide type argument.")
   return(pp)
 }
+
+
